{#
# This file is part of Invenio.
# Copyright (C) 2016 CERN.
#
# Invenio is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the
# License, or (at your option) any later version.
#
# Invenio is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Invenio; if not, write to the
# Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
# MA 02111-1307, USA.
#
# In applying this license, CERN does not
# waive the privileges and immunities granted to it by virtue of its status
# as an Intergovernmental Organization or submit itself to any jurisdiction.
#}

{# Generate a list different ways to embed a badge. #}
{%- macro badges_formats_list(image_filename, target, alternative='DOI') %}
    <h4>
        <small>Markdown</small>
    </h4>
    <h4>
        <pre>[![{{ alternative }}]({{ image_filename }})]({{ target }})</pre>
    </h4>
    <h4>
        <small>reStructedText</small>
    </h4>
    <h4>
        <pre>.. image:: {{ image_filename }}
   :target: {{ target }}</pre>
    </h4>
    <h4>
        <small>HTML</small>
    </h4>
    <h4>
      <pre>&lt;a href="{{ target }}"&gt;&lt;img src="{{ image_filename }}" alt="{{ alternative }}"&gt;&lt;/a&gt;</pre>
    </h4>

    <h4>
        <small>Image URL</small>
    </h4>
    <h4>
      <pre>{{ image_filename }}</pre>
    </h4>

    <h4>
        <small>Target URL</small>
    </h4>
    <h4>
      <pre>{{ target }}</pre>
    </h4>
{%- endmacro %}
